@@ -97,17 +97,20 @@ extern "C" {
 CannaFactory::CannaFactory (const String &lang,
                             const String &uuid,
                             const ConfigPointer &config)
-    : m_uuid (uuid),
-      m_config (config),
+    : m_uuid                   (uuid),
+      m_config                 (config),
       m_specify_init_file_name (SCIM_CANNA_CONFIG_SPECIFY_INIT_FILE_NAME_DEFAULT),
-      m_specify_server_name (SCIM_CANNA_CONFIG_SPECIFY_SERVER_NAME_DEFAULT),
-      m_init_file_name (SCIM_CANNA_CONFIG_INIT_FILE_NAME_DEFAULT),
-      m_server_name (SCIM_CANNA_CONFIG_SERVER_NAME_DEFAULT)
+      m_specify_server_name    (SCIM_CANNA_CONFIG_SPECIFY_SERVER_NAME_DEFAULT),
+      m_init_file_name         (SCIM_CANNA_CONFIG_INIT_FILE_NAME_DEFAULT),
+      m_server_name            (SCIM_CANNA_CONFIG_SERVER_NAME_DEFAULT),
+      m_on_off                 (SCIM_CANNA_CONFIG_ON_OFF_DEFAULT)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create Canna Factory :\n";
     SCIM_DEBUG_IMENGINE(1) << "  Lang : " << lang << "\n";
     SCIM_DEBUG_IMENGINE(1) << "  UUID : " << uuid << "\n";
 
+    scim_string_to_key_list (m_on_off_key, SCIM_CANNA_CONFIG_ON_OFF_KEY_DEFAULT);
+
     if (lang.length () >= 2)
         set_languages (lang);
 
@@ -131,9 +134,19 @@ CannaFactory::get_name () const
 WideString
 CannaFactory::get_authors () const
 {
-    return utf8_mbstowcs (
-        _("Copyright (C) 2005 Hiroyuki Ikezoe <poincare@ikezoe.net>\n"
-          "Copyright (C) 2005 Takuro Ashie <ashie@homa.ne.jp>"));
+    const char *package =
+        PACKAGE "-" PACKAGE_VERSION "\n"
+        "\n";
+    const char *authors =
+        _("Authors of scim-canna:\n"
+          "  Copyright (C) 2005 Takuro Ashie <ashie@homa.ne.jp>\n"
+          "  Copyright (C) 2004 Hiroyuki Ikezoe <poincare@ikezoe.net>\n"
+          "  \n"
+          "Authors of Canna:\n"
+          "  Copyright (C) 1990-1997 NEC Corporation, Tokyo, Japan.\n"
+          "  Copyright (C) 2002-2004 Canna Project.\n");
+
+    return utf8_mbstowcs (package) + utf8_mbstowcs (authors);
 }
 
 WideString
@@ -145,7 +158,54 @@ CannaFactory::get_credits () const
 WideString
 CannaFactory::get_help () const
 {
-    return WideString ();
+    const char *title = 
+        _("Basic operation:\n"
+          "  \n");
+
+    const char *text1 = 
+        _("1. Switch input mode:\n"
+          "  You can toggle on/off Japanese mode by pressing Zenkaku_Hankaku key or\n"
+          "  Shift+Space.\n"
+          "  \n");
+
+    const char *text2 = 
+        _("2. Input hiragana and katakana:\n"
+          "  You can input hiragana by inputting romaji. The preedit string can be\n"
+          "  converted to katakana or alphabet by pressing Control+N or Control+P.\n"
+          "  If you want to cancel inputting, please press Control+G\n"
+          "  \n");
+
+    const char *text3 = 
+        _("3. Convert to kanji:\n"
+          "  After inputting hiragana, you can convert it to kanji by pressing Space\n"
+          "  key. When you press Space key once again, available candidates will be\n"
+          "  shown. Press Space or Control+F to select a next candidate, and press\n"
+          "  Control+B to select a previous candidate. Press Control+G to hide\n"
+          "  candidates. Then you can commit the preedit string by pressing Enter\n"
+          "  key or Control+M.\n"
+          "  \n");
+
+    const char *text4 = 
+        _("4. Modify sentence segments:\n"
+          "  After converting to kanji and before showing candidates or commit, you\n"
+          "  can modify sentence segments. Press left and right cursor key or\n"
+          "  Control+F and Control+B to select a next or previous segment. Press\n"
+          "  Control+I or Control+O to shrink or extend the selected segment.\n"
+          "  \n");
+
+    const char *text5 = 
+        _("5. Additional features:\n"
+          "  You can access to additional features of Canna by pressing Home key.\n"
+          "  It includes searching kanji letters, registering a word and environment\n"
+          "  preferences.\n"
+          "  \n");
+
+    return utf8_mbstowcs (title)
+        + utf8_mbstowcs (text1)
+        + utf8_mbstowcs (text2)
+        + utf8_mbstowcs (text3)
+        + utf8_mbstowcs (text4)
+        + utf8_mbstowcs (text5);
 }
 
 String
@@ -166,34 +226,36 @@ CannaFactory::create_instance (const String &encoding, int id)
     return new CannaInstance (this, encoding, id);
 }
 
-#define APPEND_ACTION(key, func) \
-{ \
-    String name = "func", str; \
-    str = config->read (String (SCIM_CANNA_CONFIG_##key##_KEY), \
-                        String (SCIM_CANNA_CONFIG_##key##_KEY_DEFAULT)); \
-    m_actions.push_back (CannaAction (name, str, &CannaInstance::func)); \
-}
-
 void
 CannaFactory::reload_config (const ConfigPointer &config)
 {
     if (!config) return;
 
+    String str;
+
     m_specify_init_file_name
         = config->read (String (SCIM_CANNA_CONFIG_SPECIFY_INIT_FILE_NAME),
                         SCIM_CANNA_CONFIG_SPECIFY_INIT_FILE_NAME_DEFAULT);
+
     m_specify_server_name
         = config->read (String (SCIM_CANNA_CONFIG_SPECIFY_SERVER_NAME),
                         SCIM_CANNA_CONFIG_SPECIFY_SERVER_NAME_DEFAULT);
+
     m_init_file_name
         = config->read (String (SCIM_CANNA_CONFIG_INIT_FILE_NAME),
                         SCIM_CANNA_CONFIG_INIT_FILE_NAME_DEFAULT);
+
     m_server_name
         = config->read (String (SCIM_CANNA_CONFIG_SERVER_NAME),
                         String (SCIM_CANNA_CONFIG_SERVER_NAME_DEFAULT));
 
-    m_actions.clear ();
+    m_on_off
+        = config->read (String (SCIM_CANNA_CONFIG_ON_OFF),
+                        String (SCIM_CANNA_CONFIG_ON_OFF_DEFAULT));
 
-    // edit keys
-    //APPEND_ACTION (COMMIT,                  action_commit_with_learn);
+    str = config->read (String (SCIM_CANNA_CONFIG_ON_OFF_KEY),
+                        String (SCIM_CANNA_CONFIG_ON_OFF_KEY_DEFAULT));
+    scim_string_to_key_list (m_on_off_key, str);
+
+    m_actions.clear ();
 }
